@@ -45,8 +45,8 @@ func main() {
 				Language: "bash",
 			},
 			expected: code.Result{
-				Out:      "",
-				ExitCode: 1,
+				Out:      "exit status 127",
+				ExitCode: 127,
 			},
 		},
 		{
