@@ -5,15 +5,16 @@ import (
 	_ "embed"
 	"errors"
 	"fmt"
-	"github.com/maaslalani/slides/internal/file"
-	"github.com/maaslalani/slides/internal/navigation"
-	"github.com/maaslalani/slides/internal/process"
 	"io"
-	"io/ioutil"
 	"os"
 	"strings"
 	"time"
 
+	"github.com/atotto/clipboard"
+	"github.com/maaslalani/slides/internal/file"
+	"github.com/maaslalani/slides/internal/navigation"
+	"github.com/maaslalani/slides/internal/process"
+
 	"github.com/charmbracelet/bubbles/viewport"
 	tea "github.com/charmbracelet/bubbletea"
 	"github.com/charmbracelet/glamour"
@@ -31,6 +32,8 @@ const (
 	delimiter = "\n---\n"
 )
 
+// Model represents the model of this presentation, which contains all the
+// state related to the current slides.
 type Model struct {
 	Slides   []string
 	Page     int
@@ -51,6 +54,8 @@ type fileWatchMsg struct{}
 
 var fileInfo os.FileInfo
 
+// Init initializes the model and begins watching the slides file for changes
+// if it exists.
 func (m Model) Init() tea.Cmd {
 	if m.FileName == "" {
 		return nil
@@ -65,6 +70,7 @@ func fileWatchCmd() tea.Cmd {
 	})
 }
 
+// Load loads all of the content and metadata for the presentation.
 func (m *Model) Load() error {
 	var content string
 	var err error
@@ -91,7 +97,7 @@ func (m *Model) Load() error {
 
 	m.Slides = slides
 	m.Author = metaData.Author
-	m.Date = time.Now().Format(metaData.Date)
+	m.Date = metaData.Date
 	m.Paging = metaData.Paging
 	if m.Theme == nil {
 		m.Theme = styles.SelectTheme(metaData.Theme)
@@ -100,6 +106,7 @@ func (m *Model) Load() error {
 	return nil
 }
 
+// Update updates the presentation model.
 func (m Model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 	switch msg := msg.(type) {
 	case tea.WindowSizeMsg:
@@ -111,7 +118,6 @@ func (m Model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 		keyPress := msg.String()
 
 		if m.Search.Active {
-
 			switch msg.Type {
 			case tea.KeyEnter:
 				// execute current buffer
@@ -157,6 +163,15 @@ func (m Model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 				outs = append(outs, res.Out)
 			}
 			m.VirtualText = strings.Join(outs, "\n")
+		case "y":
+			blocks, err := code.Parse(m.Slides[m.Page])
+			if err != nil {
+				return m, nil
+			}
+			for _, b := range blocks {
+				_ = clipboard.WriteAll(b.Code)
+			}
+			return m, nil
 		case "ctrl+c", "q":
 			return m, tea.Quit
 		default:
@@ -183,9 +198,12 @@ func (m Model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 	return m, nil
 }
 
+// View renders the current slide in the presentation and the status bar which
+// contains the author, date, and pagination information.
 func (m Model) View() string {
 	r, _ := glamour.NewTermRenderer(m.Theme, glamour.WithWordWrap(m.viewport.Width))
 	slide := m.Slides[m.Page]
+	slide = code.HideComments(slide)
 	slide, err := r.Render(slide)
 	slide += m.VirtualText
 	if err != nil {
@@ -226,7 +244,7 @@ func readFile(path string) (string, error) {
 	if s.IsDir() {
 		return "", errors.New("can not read directory")
 	}
-	b, err := ioutil.ReadFile(path)
+	b, err := os.ReadFile(path)
 	if err != nil {
 		return "", err
 	}
@@ -273,10 +291,12 @@ func readStdin() (string, error) {
 	return b.String(), nil
 }
 
+// CurrentPage returns the current page the presentation is on.
 func (m *Model) CurrentPage() int {
 	return m.Page
 }
 
+// SetPage sets which page the presentation should render.
 func (m *Model) SetPage(page int) {
 	if m.Page == page {
 		return
@@ -286,6 +306,7 @@ func (m *Model) SetPage(page int) {
 	m.Page = page
 }
 
+// Pages returns all the slides in the presentation.
 func (m *Model) Pages() []string {
 	return m.Slides
 }
